@@ -3,6 +3,7 @@
 
 
 from functools import wraps
+from inspect   import getfullargspec
 from .files    import ArgsHandler
 
 
@@ -15,7 +16,7 @@ def intercept(func):
     def wrapper(*args, **kwargs):
         name = func.__name__
 
-        handler = ArgsHandler(name)
+        handler = ArgsHandler(name, argspec=getfullargspec(func))
         handler.save(args, kwargs)
 
         return func(*args, **kwargs)
